﻿Type=Class
Version=2.71
@EndOfDesignText@
'xIME Class module v1.01

'v1.00 Initial release
'v1.01 Added Phone.HideKeyboard and set ScreenHeight in Sub Initialize

'See the xIME thread in the Additional Libraries sub-forum for instructions

'These new read-only properties are added:
'    ScreenHeight
'    Visible
'    HardwareKeyboard

'It can be DIM'd and Initialized in any Activity,
'	but not from within a code or class module.

'IMPORTANT: DON'T FORGET to add this line to the manifest using the manifest editor
'   SetActivityAttribute(main, android:windowSoftInputMode, adjustResize|stateHidden)
'	If using in a different activity, specify that activity name instead of 'main' above.

#Event: HandleAction As Boolean
#Event: HeightChanged(NewHeight As Int, OldHeight As Int)

Sub Class_Globals
    Private IME As IME
    Private mTarget As Object
    Private mEventName As String
    Private mNewHeight As Int = -1
    Private mOldHeight As Int = -2
End Sub

' Methods

Public Sub AddHandleActionEvent(EditText As EditText)
    IME.AddHandleActionEvent(EditText)
End Sub

'Enables the HeightChanged event.
'This event Is raised when the soft keyboard state changes.
'You can use this event to resize other views to fit the new screen size.
'Note that this event will not be raised in fullscreen activities (an Android limitation).
'THIS SUB IS NECESSARY for the ScreenHeight and Visible properties to work!
Public Sub AddHeightChangedEvent
    IME.AddHeightChangedEvent
End Sub

'Hides the soft keyboard if visible
Public Sub HideKeyboard
    IME.HideKeyboard
End Sub

'Initializes the object and sets the subs that will handle the events.
'Must be called like this: IME.Initialize(Activity, "IME")
'A different EventName may be used if desired, but the Activity keyword must be used as the first argument.
Public Sub Initialize(Activity As Activity, EventName As String)
	Dim p As Phone
	p.HideKeyboard(Activity)
    Dim r As Reflector
    r.Target = r.GetActivity
    mTarget = r.RunMethod("getClass")
    mEventName = EventName
    IME.Initialize(mEventName)
	mNewHeight = Activity.Height
End Sub

'Sets a custom filter.
'EditText - The target EditText.
'DefaultInputType - Sets the keyboard mode.
'AcceptedCharacters - The accepted characters.
'Example: crete a custom filter that will accept IP addresses (numbers with multiple dots).
'SetCustomFilter(EditText1, EditText1.INPUT_TYPE_NUMBERS, "0123456789.")
Public Sub SetCustomFilter(EditText As EditText, DefaultInputType As Int, AcceptedCharacters As String)
    IME.SetCustomFilter(EditText, DefaultInputType, AcceptedCharacters)
End Sub

'Sets the focus to the given view and opens the soft keyboard.
'The keyboard will only show if the view has received the focus.
'Note: [Added] The keyboard will not try to be shown if this object thinks it's shown already.
Public Sub ShowKeyboard(View As View)
    IME.ShowKeyboard(View)
End Sub

' Events

Private Sub IME_HandleAction As Boolean
    Return CallSub(mTarget, mEventName & "_HandleAction")
End Sub

Private Sub IME_HeightChanged(NewHeight As Int, OldHeight As Int)
    mNewHeight = NewHeight
    mOldHeight = OldHeight
    CallSub3(mTarget, mEventName & "_HeightChanged", NewHeight, OldHeight)
End Sub

' Properties

'[Read only] Returns the height of the usable screen.
'If no soft keyboard is present, the entire activity screen height will be returned.
'Otherwise a lesser value will be returned representing the usable height of the screen.
Public Sub getScreenHeight As Int
    Return mNewHeight
End Sub

'[Read only] Returns the visibility of the soft keyboard.
'True = Soft keyboard is visible or popped up.
'False = Soft keyboard is not vislble or closed down out of sight.
Public Sub getVisible As Boolean
    Return (mNewHeight < mOldHeight)
End Sub

'[Read only] Returns the presence of a hardware keyboard.
'True = A hardware keyboard has been found.
'False = No hardware keyboard was found.
Public Sub getHardwareKeyboard As Boolean
    Dim ref As Reflector
    ref.Target = ref.GetContext
    ref.Target = ref.RunMethod("getResources")
    ref.Target = ref.RunMethod("getConfiguration")
    Dim keyboard As Int = ref.GetField("keyboard")
    Return (keyboard <> 1) 'KEYBOARD_NOKEYS - return true if keyboard, else return false 
End Sub